@@ -1239,6 +1239,202 @@ def test_dctrl_lint_dep_field_completely_busted_first_line(
     assert issue.severity == DiagnosticSeverity.Error
 
 
+def test_dctrl_lint_non_canonical_field_case(
+    line_linter: LintWrapper,
+) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debhelper-compat (= 13),
+    rules-requires-root: no
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    first_issue = diagnostics[0]
+
+    msg = 'Non-canonical spelling of "Rules-Requires-Root"'
+    problem_text = diag_range_to_text(lines, first_issue.range)
+    assert first_issue.message == msg
+    assert problem_text == "rules-requires-root"
+    assert f"{first_issue.range}" == "6:0-6:19"
+    assert first_issue.severity == DiagnosticSeverity.Hint
+
+
+def test_dctrl_lint_obsolete_value(
+    line_linter: LintWrapper,
+) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: main/devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debhelper-compat (= 13),
+    Rules-Requires-Root: no
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    first_issue = diagnostics[0]
+
+    msg = 'The value "main/devel" has been replaced by "devel"'
+    problem_text = diag_range_to_text(lines, first_issue.range)
+    assert first_issue.message == msg
+    assert problem_text == "main/devel"
+    assert f"{first_issue.range}" == "1:9-1:19"
+    assert first_issue.severity == DiagnosticSeverity.Warning
+
+
+def test_dctrl_lint_obsolete_fields(
+    line_linter: LintWrapper,
+) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debhelper-compat (= 13),
+    DM-Upload-Allowed: yes
+    X-Python-Version: 2.7
+    Rules-Requires-Root: no
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 2
+    first_issue, second_issue = diagnostics
+
+    msg_1 = '"DM-Upload-Allowed" is deprecated and no longer used'
+    problem_text_1 = diag_range_to_text(lines, first_issue.range)
+    assert first_issue.message == msg_1
+    assert problem_text_1 == "DM-Upload-Allowed: yes\n"
+    assert f"{first_issue.range}" == "6:0-7:0"
+    assert first_issue.severity == DiagnosticSeverity.Warning
+
+    msg_2 = '"X-Python-Version" has been replaced by "X-Python3-Version"'
+    problem_text_2 = diag_range_to_text(lines, second_issue.range)
+    assert second_issue.message == msg_2
+    assert problem_text_2 == "X-Python-Version"
+    assert f"{second_issue.range}" == "7:0-7:16"
+    assert second_issue.severity == DiagnosticSeverity.Warning
+
+
+def test_dctrl_lint_build_driver_with_rrr(
+    line_linter: LintWrapper,
+) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debputy
+    Build-Driver: debputy
+    Rules-Requires-Root: no
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    first_issue = diagnostics[0]
+
+    msg = 'The Rules-Requires-Root field is irrelevant for the Build-Driver "debputy".'
+    problem_text = diag_range_to_text(lines, first_issue.range)
+    assert first_issue.message == msg
+    assert problem_text == "Rules-Requires-Root: no\n"
+    assert f"{first_issue.range}" == "7:0-8:0"
+    assert first_issue.severity == DiagnosticSeverity.Information
+
+
+def test_dctrl_lint_dep_field_obsolete_operator(
+    line_linter: LintWrapper,
+) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debhelper-compat (= 13)
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    # Some random field comment
+    Depends: bar (> 2),
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    first_issue = diagnostics[0]
+
+    msg = 'Obsolete version operator ">" that is no longer supported.'
+    problem_text = diag_range_to_text(lines, first_issue.range)
+    assert first_issue.message == msg
+    assert problem_text == ">"
+    assert f"{first_issue.range}" == "11:14-11:15"
+    assert first_issue.severity == DiagnosticSeverity.Error
+
+
 def test_dctrl_lint_dep_field_restricted_operator(
     line_linter: LintWrapper,
 ) -> None:
@@ -1388,7 +1584,7 @@ def test_dctrl_duplicate_key(line_linter: LintWrapper) -> None:
 
     issue = diagnostics[0]
 
-    msg = "The Multi-Arch field name was used multiple times in this stanza."
+    msg = "The Multi-Arch field name was used multiple times in this stanza. Please ensure the field is only used once per stanza."
     assert issue.message == msg
     assert f"{issue.range}" == "27:0-27:10"
     assert issue.severity == DiagnosticSeverity.Error
@@ -1452,7 +1648,7 @@ def test_dctrl_lint_homepage(
     issue = diagnostics[0]
     superfluous_msg = "The field Homepage duplicates the value from the Source stanza."
     assert issue.message == superfluous_msg
-    assert f"{issue.range}" == "15:0-15:8"
+    assert f"{issue.range}" == "15:0-16:0"
     assert issue.severity == DiagnosticSeverity.Information
 
     lines = textwrap.dedent(
@@ -1755,3 +1951,36 @@ def test_spellcheck_ignore_package_names(
     diagnostics = line_linter(lines)
     print(diagnostics)
     assert not diagnostics
+
+
+def test_field_in_wrong_staza(line_linter: LintWrapper) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debhelper-compat (= 13)
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Build-Driver: debputy
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = 'The Build-Driver is defined for use in the "Source" stanza. Please move it to the right place or remove it'
+    assert issue.message == msg
+    assert f"{issue.range}" == f"10:0-10:12"
+    assert issue.severity == DiagnosticSeverity.Error
